betty.test_utils.ancestry package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.ancestry package

## Submodules

- betty.test_utils.ancestry.date module
  - `DummyHasDate`
- betty.test_utils.ancestry.description module
  - `DummyHasDescription`
- betty.test_utils.ancestry.event_type module
  - `DummyEventType`
  - `EventTypeTestBase`
    - `EventTypeTestBase.test_comes_after()`
    - `EventTypeTestBase.test_comes_before()`
- betty.test_utils.ancestry.gender module
  - `DummyGender`
  - `GenderTestBase`
- betty.test_utils.ancestry.locale module
  - `DummyHasLocale`
- betty.test_utils.ancestry.place_type module
  - `DummyPlaceType`
  - `PlaceTypeTestBase`

## Module contents

Test utilities for `betty.ancestry`.